from meilisearch_python_async.models import MeiliSearchSettings


class MeiliSearchIndexSettings(MeiliSearchSettings):
    uid: str
